# © 2024 Le Filament (<http://www.le-filament.com>)
# License AGPL-3.0 or later (http://www.gnu.org/licenses/agpl.html).

from odoo import api, fields, models
from odoo.exceptions import ValidationError

class MutualGuaranteeFundLine(models.Model):
    _name = "mutual.guarantee.fund.line"
    _description = "Ligne Fonds Mutuel de garantie"
    _check_company_auto = True
    _order = "date desc, id desc"

    guarantee_id = fields.Many2one(
        comodel_name="financial.contract.guarantee",
        string="Contrat de garantie",
        required=False,
        index=True,
    )
    partner_id = fields.Many2one(
        comodel_name="res.partner",
        related="guarantee_id.partner_id",
        string="Contact",
        store=True,
        index=True,
    )
    company_id = fields.Many2one(
        comodel_name="res.company",
        related="guarantee_id.company_id",
        string="Société",
        store=True,
        index=True,
    )
    currency_id = fields.Many2one(
        comodel_name="res.currency",
        related="guarantee_id.currency_id",
    )
    amount = fields.Monetary("Montant", required=True)
    date = fields.Date(required=True)
    type = fields.Selection(
        selection=[
            ("subscribe", "Souscription"),
            ("refund", "Remboursement"),
            ("guarantee_call", "Appel en garantie"),
            ("storing", "Mise en réserve"),
        ],
        string="Type de mouvement",
        required=True
    )
    comment = fields.Text("Commentaire")

    # ------------------------------------------------------
    # Constrains functions
    # ------------------------------------------------------
    @api.constrains("type", "amount")
    def _check_amount_type(self):
        for fmg in self:
            if fmg.type == "subscribe" and fmg.amount <= 0:
                raise ValidationError("Le montant d'une souscription doit être positif")
            elif fmg.type in ["refund", "guarantee_call", "storing"] and fmg.amount >= 0:
                raise ValidationError("Le montant d'une souscription doit être négatif")

    # ------------------------------------------------------
    # Computed fields / Search Fields
    # ------------------------------------------------------

    # ------------------------------------------------------
    # Actions
    # ------------------------------------------------------

    # ------------------------------------------------------
    # CRUD (Override ORM)
    # ------------------------------------------------------
